<?php

namespace Drupal\consent_support_paragraphs\Plugin\ConsentSupportPlugin;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\Entity\Display\EntityViewDisplayInterface;
use Drupal\consent_support\Entity\ConfigInterface;
use Drupal\consent_support\Plugin\ConsentSupportPluginBase;

/**
 * Implements Consent Support for Paragraph.
 *
 * @ConsentSupportPlugin(
 *   id = "consent_support_paragraph",
 *   label = @Translation("Paragraph"),
 *   entityType = "paragraph"
 * )
 */
class Paragraph extends ConsentSupportPluginBase {

  /**
   * {@inheritdoc}
   */
  public function processDisplay(array &$build, ContentEntityInterface $entity, EntityViewDisplayInterface $display, ConfigInterface $config): void {
    parent::processDisplay($build, $entity, $display, $config);

    $fields = $entity->getFieldDefinitions();
    // Skip our own additional fields.
    $fields = array_diff_key($fields, array_flip($this->getFieldNamesToIgnore()));

    $supported_types = [
      'iframe',
      'string',
      'string_long',
      'text',
      'text_long',
      'text_with_summary',
    ];

    foreach ($fields as $field_name => $field) {

      // Find the fields containing Html elements. Any string or text field in
      // the build array is a potential target.
      if (in_array($field->getType(), $supported_types) && isset($build[$field_name])) {

        /** @var \Drupal\Core\Field\FieldItemInterface $item */
        $field_items = $entity->get($field_name);
        foreach ($field_items as $index => $item) {

          try {

            // Support Iframe 8.x-2.x.
            if ($field->getType() === 'iframe') {
              $this->processor->processIframeRenderArray($build[$field_name][$index], $config);
            }
            // Support text fields.
            else {
              switch ($build[$field_name][$index]['#type']) {

                case 'inline_template':

                  // Attach provider cache tags if a category was forced.
                  if ($this->processor->processHtmlAsString($build[$field_name][$index]['#context']['value'], $config)) {
                    $this->processor->addCacheTags($build[$field_name]);
                  }

                  $this->processor->getCookiePro()->addConfigCacheTags($build[$field_name]);
                  $this->attachNoConsentLibrary($build);

                  break;

                case 'processed_text':

                  // Attach provider cache tags if a category was forced.
                  if ($this->processor->processHtmlAsString($build[$field_name][$index]['#text'], $config)) {
                    $this->processor->addCacheTags($build[$field_name]);
                  }

                  $this->processor->getCookiePro()->addConfigCacheTags($build[$field_name]);
                  $this->attachNoConsentLibrary($build);

                  break;

                default:
              }
            }
          }
          catch (\Exception $exception) {
            // Silent fails for now.
            continue;
          }
        }
      }
    }
  }

}
